@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2009 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,8 +19,9 @@
 #include "infofile.h"
 #include <QFileInfo>
 #include <QCoreApplication>
-#include "helper.h"
+#include "discname.h"
 #include "constants.h"
+#include "images.h"
 
 
 InfoFile::InfoFile() {
@@ -49,10 +50,11 @@ QString InfoFile::getInfo(MediaData md) {
 		case TYPE_STREAM : 	icon = "type_url.png"; break;
 		default 		: 	icon = "type_unknown.png";
 	}
-	icon = "<img src=\":/icons-png/" + icon + "\"> ";
+	icon = "<img src=\"" + Images::file(icon) + "\"> ";
 
 	if (md.type == TYPE_DVD) {
-		s += title( icon + "dvd://" + QString::number(Helper::dvdSplitTitle(md.filename) ) );
+		DiscData disc_data = DiscName::split(md.filename);
+		s += title( icon + disc_data.protocol + "://" + QString::number(disc_data.title) );
 	} else {
 		s += title( icon + md.displayName() );
 	}
@@ -176,7 +178,7 @@ QString InfoFile::getInfo(MediaData md) {
 		s += closePar();
 	}
 
-	return s;
+	return "<html><body bgcolor=\"white\"><font color=\"black\">"+ s + "</font></body></html>";
 }
 
 QString InfoFile::title(QString text) {
@@ -195,9 +197,9 @@ QString InfoFile::closePar() {
 
 QString InfoFile::openItem() {
 	if (row % 2 == 1)
-		return "<tr bgcolor=\"#c4daf4\">";
+		return "<tr bgcolor=\"lavender\">";
 	else
-		return "<tr bgcolor=\"#ffffc6\">";
+		return "<tr bgcolor=\"powderblue\">";
 }
 
 QString InfoFile::closeItem() {
