@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2009 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -114,6 +114,10 @@ static QRegExp rx_endoffile("^Exiting... \\(End of file\\)|^ID_EXIT=EOF");
 static QRegExp rx_mkvchapters("\\[mkv\\] Chapter (\\d+) from");
 static QRegExp rx_aspect2("^Movie-Aspect is ([0-9,.]+):1");
 static QRegExp rx_fontcache("^\\[ass\\] Updating font cache|^\\[ass\\] Init");
+#if DVDNAV_SUPPORT
+static QRegExp rx_dvdnav_switch_title("^DVDNAV, switched to title: (\\d+)");
+static QRegExp rx_dvdnav_length("^ANS_length=(.*)");
+#endif
  
 // VCD
 static QRegExp rx_vcd("^ID_VCD_TRACK_(\\d+)_MSF=(.*)");
@@ -121,7 +125,6 @@ static QRegExp rx_vcd("^ID_VCD_TRACK_(\\d+)_MSF=(.*)");
 // Audio CD
 static QRegExp rx_cdda("^ID_CDDA_TRACK_(\\d+)_MSF=(.*)");
 
-
 //Subtitles
 static QRegExp rx_subtitle("^ID_(SUBTITLE|FILE_SUB|VOBSUB)_ID=(\\d+)");
 static QRegExp rx_sid("^ID_(SID|VSID)_(\\d+)_(LANG|NAME)=(.*)");
@@ -234,6 +237,9 @@ void MplayerProcess::parseLine(QByteArray ba) {
 		// Emulates mplayer version in Ubuntu:
 		//if (line.startsWith("MPlayer 1.0rc1")) line = "MPlayer 2:1.0~rc1-0ubuntu13.1 (C) 2000-2006 MPlayer Team";
 
+		// Emulates unknown version
+		//if (line.startsWith("MPlayer SVN")) line = "MPlayer lalksklsjjakksja";
+
 		emit lineAvailable(line);
 
 		// Parse other things
@@ -364,6 +370,22 @@ void MplayerProcess::parseLine(QByteArray ba) {
 		}
 #endif
 
+#if DVDNAV_SUPPORT
+		if (rx_dvdnav_switch_title.indexIn(line) > -1) {
+			int title = rx_dvdnav_switch_title.cap(1).toInt();
+			qDebug("MplayerProcess::parseLine: dvd title: %d", title);
+			emit receivedDVDTitle(title);
+		}
+		if (rx_dvdnav_length.indexIn(line) > -1) {
+			double length = rx_dvdnav_length.cap(1).toDouble();
+			qDebug("MplayerProcess::parseLine: length: %f", length);
+			if (length != md.duration) {
+				md.duration = length;
+				emit receivedDuration(length);
+			}
+		}
+#endif
+
 		// The following things are not sent when the file has started to play
 		// (or if sent, smplayer will ignore anyway...)
 		// So not process anymore, if video is playing to save some time
