@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2009 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -21,7 +21,6 @@
 #include "images.h"
 #include "preferences.h"
 #include <QColorDialog>
-#include <QNetworkProxy>
 
 PrefAdvanced::PrefAdvanced(QWidget * parent, Qt::WindowFlags f)
 	: PrefWidget(parent, f )
@@ -72,12 +71,6 @@ void PrefAdvanced::retranslateStrings() {
 
 	monitoraspect_combo->setItemText(0, tr("Auto") );
 
-	int proxy_type_item = proxy_type_combo->currentIndex();
-	proxy_type_combo->clear();
-	proxy_type_combo->addItem( tr("Http"), QNetworkProxy::HttpProxy);
-	proxy_type_combo->addItem( tr("Socks5"), QNetworkProxy::Socks5Proxy);
-	proxy_type_combo->setCurrentIndex(proxy_type_item);
-
 	createHelp();
 }
 
@@ -107,14 +100,6 @@ void PrefAdvanced::setData(Preferences * pref) {
     setMplayerLogName( pref->mplayer_log_saveto );
 
 	setUseShortNames( pref->use_short_pathnames );
-
-	// Proxy
-	setUseProxy( pref->use_proxy );
-	setProxyHostname( pref->proxy_host );
-	setProxyPort( pref->proxy_port );
-	setProxyUsername( pref->proxy_username );
-	setProxyPassword( pref->proxy_password );
-	setProxyType( pref->proxy_type );
 }
 
 void PrefAdvanced::getData(Preferences * pref) {
@@ -164,21 +149,6 @@ void PrefAdvanced::getData(Preferences * pref) {
     pref->mplayer_log_saveto = mplayerLogName();
 
 	pref->use_short_pathnames = useShortNames();
-
-	// Proxy
-	proxy_changed = ( (pref->use_proxy != useProxy()) || 
-                      (pref->proxy_host != proxyHostname()) ||
-                      (pref->proxy_port != proxyPort()) ||
-                      (pref->proxy_username != proxyUsername()) ||
-                      (pref->proxy_password != proxyPassword()) ||
-                      (pref->proxy_type != proxyType()) );
-
-	pref->use_proxy = useProxy();
-	pref->proxy_host = proxyHostname();
-	pref->proxy_port = proxyPort();
-	pref->proxy_username = proxyUsername();
-	pref->proxy_password = proxyPassword();
-	pref->proxy_type = proxyType();
 }
 
 void PrefAdvanced::setMonitorAspect(QString asp) {
@@ -288,12 +258,12 @@ bool PrefAdvanced::useIdx() {
 	return idx_check->isChecked();
 }
 
-void PrefAdvanced::setUseCorrectPts(bool b) {
-	correct_pts_check->setChecked(b);
+void PrefAdvanced::setUseCorrectPts(Preferences::OptionState value) {
+	correct_pts_combo->setState(value);
 }
 
-bool PrefAdvanced::useCorrectPts() {
-	return correct_pts_check->isChecked();
+Preferences::OptionState PrefAdvanced::useCorrectPts() {
+	return correct_pts_combo->state();
 }
 
 void PrefAdvanced::setActionsToRun(QString actions) {
@@ -357,57 +327,6 @@ QString PrefAdvanced::mplayerLogName() {
     return log_mplayer_save_name->text();
 }
 
-void PrefAdvanced::setUseProxy(bool b) {
-	use_proxy_check->setChecked(b);
-}
-
-bool PrefAdvanced::useProxy() {
-	return 	use_proxy_check->isChecked();
-}
-
-void PrefAdvanced::setProxyHostname(QString host) {
-	proxy_hostname_edit->setText(host);
-}
-
-QString PrefAdvanced::proxyHostname() {
-	return proxy_hostname_edit->text();
-}
-
-void PrefAdvanced::setProxyPort(int port) {
-	proxy_port_spin->setValue(port);
-}
-
-int PrefAdvanced::proxyPort() {
-	return proxy_port_spin->value();
-}
-
-void PrefAdvanced::setProxyUsername(QString username) {
-	proxy_username_edit->setText(username);
-}
-
-QString PrefAdvanced::proxyUsername() {
-	return proxy_username_edit->text();
-}
-
-void PrefAdvanced::setProxyPassword(QString password) {
-	proxy_password_edit->setText(password);
-}
-
-QString PrefAdvanced::proxyPassword() {
-	return proxy_password_edit->text();
-}
-
-void PrefAdvanced::setProxyType(int type) {
-	int index = proxy_type_combo->findData(type);
-	if (index == -1) index = 0;
-	proxy_type_combo->setCurrentIndex(index);
-}
-
-int PrefAdvanced::proxyType() {
-	int index = proxy_type_combo->currentIndex();
-	return proxy_type_combo->itemData(index).toInt();
-}
-
 
 void PrefAdvanced::createHelp() {
 	clearHelp();
@@ -432,7 +351,7 @@ void PrefAdvanced::createHelp() {
            "seeking (i.e. not with stdin, pipe, etc).<br> "
            "<b>Note:</b> the creation of the index may take some time.") );
 
-	setWhatsThis(correct_pts_check, tr("Correct pts"),
+	setWhatsThis(correct_pts_combo, tr("Correct pts"),
 		tr("Switches MPlayer to an experimental mode where timestamps for "
            "video frames are calculated differently and video filters which "
            "add new frames or modify timestamps of existing ones are "
@@ -498,25 +417,6 @@ void PrefAdvanced::createHelp() {
 	setWhatsThis(ipv6_button, tr("IPv6"),
 		tr("Use IPv6 on network connections. Falls back on IPv4 automatically."));
 
-	setWhatsThis(use_proxy_check, tr("Enable proxy"),
-		tr("Enable/disable the use of the proxy.") );
-
-	setWhatsThis(proxy_hostname_edit, tr("Host"),
-		tr("The host name of the proxy.") );
-
-	setWhatsThis(proxy_port_spin, tr("Port"),
-		tr("The port of the proxy.") );
-
-	setWhatsThis(proxy_username_edit, tr("Username"),
-		tr("If the proxy requires authentication, this sets the username.") );
-
-	setWhatsThis(proxy_password_edit, tr("Password"),
-		tr("The password for the proxy. <b>Warning:</b> the password will be saved "
-           "as plain text in the configuration file.") );
-
-	setWhatsThis(proxy_type_combo, tr("Type"),
-		tr("Select the proxy type to be used.") );
-
 	addSectionTitle(tr("Logs"));
 
 	setWhatsThis(log_smplayer_check, tr("Log SMPlayer output"),
