@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2009 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -40,18 +40,14 @@
 
 #include <cmath>
 
-// Workaround for Windows
-#ifdef Q_OS_WIN
-#define CD_TO_TEMP_DIR 1
-#endif
-
 #define RENAME_PICTURES 0
 
-VideoPreview::VideoPreview(QString mplayer_path, QWidget * parent, Qt::WindowFlags f) : QWidget(parent, f)
+VideoPreview::VideoPreview(QString mplayer_path, QWidget * parent) : QWidget(parent, Qt::Window)
 {
 	setMplayerPath(mplayer_path);
 
 	set = 0; // settings
+	save_last_directory = true;
 
 	prop.input_video.clear();
 	prop.dvd_device.clear();
@@ -73,6 +69,7 @@ VideoPreview::VideoPreview(QString mplayer_path, QWidget * parent, Qt::WindowFla
 	w_contents = new QWidget(this);
 	QPalette p = w_contents->palette();
 	p.setColor(w_contents->backgroundRole(), Qt::white);
+	p.setColor(w_contents->foregroundRole(), Qt::black);
 	w_contents->setPalette(p);
 
 	info = new QLabel(this);
@@ -130,7 +127,7 @@ void VideoPreview::retranslateStrings() {
 	progress->setWindowTitle(tr("Video preview"));
 	progress->setCancelButtonText( tr("Cancel") );
 
-	foot->setText("<i>"+ tr("Generated by SMPlayer") +" (http://smplayer.sf.net)</i>");
+	foot->setText("<i>"+ tr("Generated by SMPlayer") +" </i>");
 }
 
 void VideoPreview::setMplayerPath(QString mplayer_path) {
@@ -265,18 +262,10 @@ bool VideoPreview::runMplayer(int seek, double aspect_ratio) {
 
 	if (prop.extract_format == PNG) {
 		args << "-vo"
-		#ifdef CD_TO_TEMP_DIR
-		<< "png";
-		#else
-		<< "png:outdir="+full_output_dir;
-		#endif
+		<< "png:outdir=\""+full_output_dir+"\"";
 	} else {
 		args << "-vo"
-		#ifdef CD_TO_TEMP_DIR
-		<< "jpeg";
-		#else
-		<< "jpeg:outdir="+full_output_dir;
-		#endif
+		<< "jpeg:outdir=\""+full_output_dir+"\"";
 	}
 
 	args << "-frames" << "6" << "-ss" << QString::number(seek);
@@ -302,10 +291,6 @@ bool VideoPreview::runMplayer(int seek, double aspect_ratio) {
 	qDebug("VideoPreview::runMplayer: command: %s", command.toUtf8().constData());
 
 	QProcess p;
-	#ifdef CD_TO_TEMP_DIR
-	p.setWorkingDirectory(full_output_dir);
-	qDebug("VideoPreview::runMplayer: changing working directory of the process to '%s'", full_output_dir.toUtf8().constData());
-	#endif
 	p.start(mplayer_bin, args);
 	if (!p.waitForFinished()) {
 		qDebug("VideoPreview::runMplayer: error running process");
@@ -502,9 +487,12 @@ void VideoPreview::saveImage() {
 	qDebug("VideoPreview::saveImage");
 
 	// Proposed name
-	QString proposed_name = last_directory;
+	QString proposed_name = "";
+	if (save_last_directory) proposed_name = last_directory;
+
 	QFileInfo fi(prop.input_video);
 	if (fi.exists()) {
+		if (!save_last_directory) proposed_name = fi.absolutePath();
 		QString extension = (extractFormat()==PNG) ? "png" : "jpg";
 		proposed_name += "/"+ fi.completeBaseName() +"_preview."+ extension;
 	}
@@ -536,8 +524,8 @@ void VideoPreview::saveImage() {
 	}
 }
 
-bool VideoPreview::showConfigDialog() {
-	VideoPreviewConfigDialog d(this);
+bool VideoPreview::showConfigDialog(QWidget * parent) {
+	VideoPreviewConfigDialog d(parent);
 
 	d.setVideoFile( videoFile() );
 	d.setDVDDevice( DVDDevice() );
@@ -548,6 +536,7 @@ bool VideoPreview::showConfigDialog() {
 	d.setDisplayOSD( displayOSD() );
 	d.setAspectRatio( aspectRatio() );
 	d.setFormat( extractFormat() );
+	d.setSaveLastDirectory( save_last_directory );
 
 	if (d.exec() == QDialog::Accepted) {
 		setVideoFile( d.videoFile() );
@@ -559,6 +548,7 @@ bool VideoPreview::showConfigDialog() {
 		setDisplayOSD( d.displayOSD() );
 		setAspectRatio( d.aspectRatio() );
 		setExtractFormat(d.format() );
+		save_last_directory = d.saveLastDirectory();
 
 		return true;
 	}
@@ -577,7 +567,11 @@ void VideoPreview::saveSettings() {
 	set->setValue("max_width", maxWidth());
 	set->setValue("osd", displayOSD());
 	set->setValue("format", extractFormat());
-	set->setValue("last_directory", last_directory);
+	set->setValue("save_last_directory", save_last_directory);
+
+	if (save_last_directory) {
+		set->setValue("last_directory", last_directory);
+	}
 
 	set->setValue("filename", videoFile());
 	set->setValue("dvd_device", DVDDevice());
@@ -596,6 +590,7 @@ void VideoPreview::loadSettings() {
 	setMaxWidth( set->value("max_width", maxWidth()).toInt() );
 	setDisplayOSD( set->value("osd", displayOSD()).toBool() );
 	setExtractFormat( (ExtractFormat) set->value("format", extractFormat()).toInt() );
+	save_last_directory = set->value("save_last_directory", save_last_directory).toBool();
 	last_directory = set->value("last_directory", last_directory).toString();
 
 	setVideoFile( set->value("filename", videoFile()).toString() );
