@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2009 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -25,16 +25,27 @@
 #define WINFILEASSOC_H
 
 #include <QString>
+#include <QStringList>
+
 class WinFileAssoc
 {
 protected:
 	QString m_ClassId; //Application ClassId
-public:
-	WinFileAssoc(const QString& ClassId);
-	bool CreateFileAssociation(const QString& fileExtension);
-	bool RestoreFileAssociation(const QString& fileExtension);
+	QString m_ClassId2; //The ClassId created by explorer if user selects 'Open With...', usually smplayer.exe
+	QString m_AppName;
+
+protected:
 	bool CreateClassId(const QString& executablePath, const QString& friendlyName); 
 	bool RemoveClassId();
+	bool VistaGetDefaultApps(const QStringList &extensions, QStringList& registeredExt);
+	int  VistaSetAppsAsDefault(const QStringList& extensions);
+public:
+	WinFileAssoc(const QString ClassId = "MPlayerFileVideo", const QString AppName="SMPlayer");
+	//Checks the registry to see which extensions are registered with SMPlayer
+	bool GetRegisteredExtensions(const QStringList& extensionsToCheck, QStringList& registeredExtensions);
+
+	int CreateFileAssociations(const QStringList& fileExtensions); 
+	int RestoreFileAssociations(const QStringList& fileExtensions);
 };
 
 #endif
